@@ -320,6 +320,34 @@ md_log_severity_levels <- paste0(
   collapse = ", "
 )
 
+#' Returns the active span, if any
+#'
+#' This is sometimes useful, to add additional attributes or links to the
+#' currently active span.
+#'
+#' @return The active span, an [otel_span] object, if any, or an invalid
+#'   span if there is no active span.
+#' @export
+#' @examples
+#' fun <- function() {
+#'   otel::start_local_active_span("fun")
+#'   spn <- otel::get_active_span()
+#'   spn$set_attribute("key", "attribute-value")
+#' }
+#' fun()
+
+# safe start
+get_active_span <- function() {
+  tryCatch({                                                         # safe
+    trc <- get_tracer()
+    trc$get_active_span()
+  }, error = function(err) {                                         # safe
+    errmsg("OpenTelemetry error: ", conditionMessage(err))           # safe
+    span_noop$new(NA_character_)                                     # safe
+  })                                                                 # safe
+}
+# safe end
+
 #' Returns the active span context
 #'
 #' This is sometimes useful for logs or metrics, to associate
@@ -707,14 +735,11 @@ is_measuring_enabled_safe <- is_measuring_enabled
 
 #' Log an OpenTelemetry log message
 #'
-#' @param msg Log message, may contain R expressions to evaluate within
-#'   braces.
+#' @param msg Log message.
 #' @param severity Log severity, a string, one of
 #'   `r md_log_severity_levels`.
 #' @param ... Additional arguments are passed to the `$log()` method of
 #'   the logger.
-#' @param .envir Environment to evaluate the interpolated expressions of
-#'   the log message in.
 #' @param logger Logger to use. If not an OpenTelemetry logger object
 #'   ([otel_logger]), then it passed to [get_logger()] to get a logger.
 #' @return The logger, invisibly.
@@ -731,14 +756,13 @@ log <- function(
   msg,
   ...,
   severity = "info",
-  .envir = parent.frame(),
   logger = NULL
 ) {
   tryCatch({                                                         # safe
     if (!inherits(logger, "otel_logger")) {
       logger <- get_logger()
     }
-    logger$log(msg, severity, ..., .envir = .envir)
+    logger$log(msg, severity, ...)
     invisible(logger)
   }, error = function(err) {                                         # safe
     errmsg("OpenTelemetry error: ", conditionMessage(err))           # safe
@@ -758,14 +782,13 @@ log_safe <- log
 log_trace <- function(
   msg,
   ...,
-  .envir = parent.frame(),
   logger = NULL
 ) {
   tryCatch({                                                         # safe
     if (!inherits(logger, "otel_logger")) {
       logger <- get_logger()
     }
-    logger$log(msg, "trace", ..., .envir = .envir)
+    logger$log(msg, "trace", ...)
     invisible(logger)
   }, error = function(err) {                                         # safe
     errmsg("OpenTelemetry error: ", conditionMessage(err))           # safe
@@ -785,14 +808,13 @@ log_trace_safe <- log_trace
 log_debug <- function(
   msg,
   ...,
-  .envir = parent.frame(),
   logger = NULL
 ) {
   tryCatch({                                                         # safe
     if (!inherits(logger, "otel_logger")) {
       logger <- get_logger()
     }
-    logger$log(msg, "debug", ..., .envir = .envir)
+    logger$log(msg, "debug", ...)
     invisible(logger)
   }, error = function(err) {                                         # safe
     errmsg("OpenTelemetry error: ", conditionMessage(err))           # safe
@@ -812,14 +834,13 @@ log_debug_safe <- log_debug
 log_info <- function(
   msg,
   ...,
-  .envir = parent.frame(),
   logger = NULL
 ) {
   tryCatch({                                                         # safe
     if (!inherits(logger, "otel_logger")) {
       logger <- get_logger()
     }
-    logger$log(msg, "info", ..., .envir = .envir)
+    logger$log(msg, "info", ...)
     invisible(logger)
   }, error = function(err) {                                         # safe
     errmsg("OpenTelemetry error: ", conditionMessage(err))           # safe
@@ -839,14 +860,13 @@ log_info_safe <- log_info
 log_warn <- function(
   msg,
   ...,
-  .envir = parent.frame(),
   logger = NULL
 ) {
   tryCatch({                                                         # safe
     if (!inherits(logger, "otel_logger")) {
       logger <- get_logger()
     }
-    logger$log(msg, "warn", ..., .envir = .envir)
+    logger$log(msg, "warn", ...)
     invisible(logger)
   }, error = function(err) {                                         # safe
     errmsg("OpenTelemetry error: ", conditionMessage(err))           # safe
@@ -866,14 +886,13 @@ log_warn_safe <- log_warn
 log_error <- function(
   msg,
   ...,
-  .envir = parent.frame(),
   logger = NULL
 ) {
   tryCatch({                                                         # safe
     if (!inherits(logger, "otel_logger")) {
       logger <- get_logger()
     }
-    logger$log(msg, "error", ..., .envir = .envir)
+    logger$log(msg, "error", ...)
     invisible(logger)
   }, error = function(err) {                                         # safe
     errmsg("OpenTelemetry error: ", conditionMessage(err))           # safe
@@ -893,14 +912,13 @@ log_error_safe <- log_error
 log_fatal <- function(
   msg,
   ...,
-  .envir = parent.frame(),
   logger = NULL
 ) {
   tryCatch({                                                         # safe
     if (!inherits(logger, "otel_logger")) {
       logger <- get_logger()
     }
-    logger$log(msg, "fatal", ..., .envir = .envir)
+    logger$log(msg, "fatal", ...)
     invisible(logger)
   }, error = function(err) {                                         # safe
     errmsg("OpenTelemetry error: ", conditionMessage(err))           # safe
